@@ -217,7 +217,6 @@ int load_config(struct daemon_conf *config, log_test_t lt)
 	fclose(f);
 	return 0;
 }
-hidden_def(load_config);
 
 static char *get_line(FILE *f, char *buf)
 {
@@ -418,5 +417,4 @@ void free_config(struct daemon_conf *config)
 	free((void *)config->disk_full_exe);
 	free((void *)config->disk_error_exe);
 }
-hidden_def(free_config);
 
