@@ -19,12 +19,11 @@
  * Authors:
  *	Steve Grubb <sgrubb@redhat.com>
  */
-#ifndef AUPARSE_INTERNAL_HEADER_
+#ifndef AUPARSE_INTERNAL_HEADER
 #define AUPARSE_INTERNAL_HEADER
 
 #include "auparse-defs.h"
 #include "ellist.h"
-#include "rlist.h"
 #include "auditd-config.h"
 #include "data_buf.h"
 #include <stdio.h>
@@ -63,7 +62,7 @@ struct nv_pair {
 	const char *name;
 };
 
-typedef struct opaque
+struct opaque
 {
 	ausource_t source;		// Source type
 	char **source_list;		// Array of buffers, or array of
@@ -78,13 +77,13 @@ typedef struct opaque
 	int line_pushed;		// True if retrieve_next_line() 
 					//	returns same input
 	event_list_t le;		// Linked list of record in same event
-	aurule_list_t rules;		// Search rules
+	struct expr *expr;		// Search expression or NULL
 	char *find_field;		// Used to store field name when
 					//	 searching
 	austop_t search_where;		// Where to put the cursors on a match
-	ausearch_rule_t search_how;	// How the rules are to be applied
 	auparser_state_t parse_state;	// parsing state
-	regex_t regex;			// compiled regex
+	regex_t regex;			// compiled regex if regex_valid != 0
+	int regex_valid;
 	DataBuf databuf;		// input data
 
 	// function to call to notify user of parsing changes
@@ -94,20 +93,11 @@ typedef struct opaque
 
 	// function to call when user_data is destroyed
 	void (*callback_user_data_destroy)(void *user_data);
-}auparse_state_t;
-
-// This is the main messaging function used internally
-extern int audit_send_user_message(int fd, int type, const char *message);
-
-// libaudit.c
-hidden_proto(audit_send_user_message)
+};
 
 // auditd-config.c
-hidden_proto(load_config)
-hidden_proto(free_config)
-
-// rlist.c
-hidden_proto(aurule_next)
+int load_config(struct daemon_conf *config, log_test_t lt) hidden;
+void free_config(struct daemon_conf *config) hidden;
 
 
 #ifdef __cplusplus
