@@ -345,4 +345,10 @@ _S(323, "eventfd")
 _S(324, "fallocate")
 _S(325, "timerfd_settime")
 _S(326, "timerfd_gettime")
+_S(327, "signalfd4")
+_S(328, "eventfd2")
+_S(329, "epoll_create1")
+_S(330, "dup3")
+_S(331, "pipe2")
+_S(332, "inotify_init1")
 
