@@ -303,4 +303,10 @@ _S(1309, "eventfd")
 _S(1310, "timerfd_create")
 _S(1311, "timerfd_settime")
 _S(1312, "timerfd_gettime")
+_S(1313, "signalfd4")
+_S(1314, "eventfd2")
+_S(1315, "epoll_create1")
+_S(1316, "dup3")
+_S(1317, "pipe2")
+_S(1318, "inotify_init1")
 
