@@ -174,4 +174,11 @@ _S(AUDIT_DEV_ALLOC,                  "DEV_ALLOC"                     )
 _S(AUDIT_DEV_DEALLOC,                "DEV_DEALLOC"                   )
 _S(AUDIT_FS_RELABEL,                 "FS_RELABEL"                    )
 _S(AUDIT_USER_MAC_POLICY_LOAD,       "USER_MAC_POLICY_LOAD"          )
+_S(AUDIT_CRYPTO_TEST_USER,           "CRYPTO_TEST_USER"              )
+_S(AUDIT_CRYPTO_PARAM_CHANGE_USER,   "CRYPTO_PARAM_CHANGE_USER"      )
+_S(AUDIT_CRYPTO_LOGIN,               "CRYPTO_LOGIN"                  )
+_S(AUDIT_CRYPTO_LOGOUT,              "CRYPTO_LOGOUT"                 )
+_S(AUDIT_CRYPTO_KEY_USER,            "CRYPTO_KEY_USER"               )
+_S(AUDIT_CRYPTO_FAILURE_USER,        "CRYPTO_FAILURE_USER"           )
+_S(AUDIT_CRYPTO_REPLAY_USER,         "CRYPTO_REPLAY_USER"            )
 
