@@ -326,4 +326,10 @@ _S(309, "fallocate")
 _S(310, "subpage_prot")
 _S(311, "timerfd_settime")
 _S(312, "timerfd_gettime")
+_S(313, "signalfd4")
+_S(314, "eventfd2")
+_S(315, "epoll_create1")
+_S(316, "dup3")
+_S(317, "pipe2")
+_S(318, "inotify_init1")
 
