@@ -308,4 +308,11 @@ _S(284, "eventfd")
 _S(285, "fallocate")
 _S(286, "timerfd_settime")
 _S(287, "timerfd_gettime")
+_S(288, "paccept")
+_S(289, "signalfd4")
+_S(290, "eventfd2")
+_S(291, "epoll_create1")
+_S(292, "dup3")
+_S(293, "pipe2")
+_S(294, "inotify_init1")
 
