@@ -1,6 +1,6 @@
 # Options dialog (handling everything but audit rules).
 #
-# Copyright (C) 2007 Red Hat, Inc.  All rights reserved.
+# Copyright (C) 2007, 2008 Red Hat, Inc.  All rights reserved.
 # This copyrighted material is made available to anyone wishing to use, modify,
 # copy, or redistribute it subject to the terms and conditions of the GNU
 # General Public License v.2.  This program is distributed in the hope that it
@@ -17,6 +17,7 @@
 # Red Hat Author: Miloslav Trmac <mitr@redhat.com>
 from gettext import gettext as _
 import os.path
+import socket
 import stat
 import string
 
@@ -80,7 +81,9 @@ class GlobalDialog(DialogBase):
                            'max_log_file_label2', 'max_log_file_rotate',
                            'max_log_file_rotate_label2', 'max_log_file_suspend',
                            'max_log_file_syslog',
-                           'num_logs',
+                           'name', 'name_format_fqd', 'name_format_hostname',
+                           'name_format_not_none', 'name_format_numeric',
+                           'name_format_user', 'num_logs',
                            'priority_boost',
                            'rate_limit', 'rate_limit_enabled',
                            'rate_limit_enabled_label2',
@@ -89,8 +92,8 @@ class GlobalDialog(DialogBase):
                            'space_left_halt', 'space_left_ignore',
                            'space_left_single', 'space_left_suspend',
                            'space_left_syslog')
-    def __init__(self):
-        DialogBase.__init__(self, 'global_config',
+    def __init__(self, parent):
+        DialogBase.__init__(self, 'global_config', parent,
                             notebook_name = 'global_config_notebook')
 
         util.connect_and_run(self.rate_limit_enabled, 'toggled',
@@ -114,6 +117,29 @@ class GlobalDialog(DialogBase):
                              self.__max_log_file_keep_logs_toggled)
         util.connect_and_run(self.max_log_file_rotate, 'toggled',
                              self.__max_log_file_rotate_toggled)
+        util.connect_and_run(self.name_format_not_none, 'toggled',
+                             self.__name_format_not_none_toggled)
+        hostname = socket.gethostname()
+        self.name_format_hostname.set_label(_('Host name as-_is (%s)')
+                                            % hostname)
+        try:
+            # AI_PASSIVE is probably not necessary, but that's what auditd uses.
+            addrs = socket.getaddrinfo(hostname, None, socket.AF_UNSPEC,
+                                       socket.SOCK_STREAM, 0,
+                                       socket.AI_ADDRCONFIG |
+                                       socket.AI_CANONNAME | socket.AI_PASSIVE)
+        except socket.gaierror:
+            addrs = ()
+        if addrs:
+            fqd_label = _('_Fully-qualified host name (%s)') % addrs[0][3]
+            numeric_label = _('I_P address (%s)') % addrs[0][4][0]
+        else:
+            fqd_label = _('_Fully-qualified host name')
+            numeric_label = _('I_P address')
+        self.name_format_fqd.set_label(fqd_label)
+        self.name_format_numeric.set_label(numeric_label)
+        util.connect_and_run(self.name_format_user, 'toggled',
+                             self.__name_format_user_toggled)
 
         util.connect_and_run(self.space_left_exec, 'toggled',
                              self.__space_left_exec_toggled)
@@ -167,6 +193,10 @@ class GlobalDialog(DialogBase):
     __kernel_fail_map = (('kernel_fail_ignore', AR.FAILURE_SILENT),
                          ('kernel_fail_syslog', AR.FAILURE_PRINTK),
                          ('kernel_fail_panic', AR.FAILURE_PANIC))
+    __name_format_map = (('name_format_hostname', AC.NAME_HOSTNAME),
+                         ('name_format_fqd', AC.NAME_FQD),
+                         ('name_format_numeric', AC.NAME_NUMERIC),
+                         ('name_format_user', AC.NAME_USER))
     __space_left_map = (('space_left_ignore', AC.FAILURE_IGNORE),
                         ('space_left_syslog', AC.FAILURE_SYSLOG),
                         ('space_left_email', AC.FAILURE_EMAIL),
@@ -214,6 +244,9 @@ class GlobalDialog(DialogBase):
         self.max_log_file_rotate.set_active(auditd.max_log_file_action ==
                                             AC.SIZE_ROTATE)
         self.num_logs.set_value(auditd.num_logs)
+        self.name_format_not_none.set_active(auditd.name_format != AC.NAME_NONE)
+        self._radio_set(auditd.name_format, self.__name_format_map)
+        _set_optional_text(self.name, auditd.name)
 
         self.space_left.set_value(auditd.space_left)
         self._radio_set(auditd.space_left_action, self.__space_left_map)
@@ -280,6 +313,14 @@ class GlobalDialog(DialogBase):
                 auditd.max_log_file_action = AC.SIZE_ROTATE
             else:
                 auditd.max_log_file_action = AC.SIZE_KEEP_LOGS
+        if self.name_format_not_none.get_active():
+            auditd.name_format = self._radio_get(self.__name_format_map)
+        else:
+            auditd.name_format = AC.NAME_NONE
+        if auditd.name_format == AC.NAME_USER:
+            auditd.name = self.name.get_text()
+        else:
+            auditd.name = None
         auditd.num_logs = self.num_logs.get_value_as_int()
         auditd.priority_boost = self.priority_boost.get_value_as_int()
         auditd.space_left = self.space_left.get_value_as_int()
@@ -309,6 +350,11 @@ class GlobalDialog(DialogBase):
             msg = self.__validate_log_file(self.log_file.get_text())
             if msg:
                 return (msg, 2, self.log_file)
+            if (self.name_format_not_none.get_active() and
+                self.name_format_user.get_active()):
+                msg = self.__validate_name(self.name.get_text())
+                if msg:
+                    return (msg, 2, self.name)
 
 	if self.space_left_email.get_active():
             msg = self.__validate_email_use()
@@ -405,9 +451,20 @@ class GlobalDialog(DialogBase):
                 return _('"%s" is not a regular file') % path
             if st.st_uid != 0:
                 return _('"%s" is not owned by root') % path
-            if ((st.st_mode & (stat.S_IRWXU | stat.S_IRWXG | stat.S_IRWXO)) !=
-                (stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)):
-                return _('Permissions of "%s" should be 0640') % path
+            if ((st.st_mode & (stat.S_IWUSR | stat.S_IXUSR | stat.S_IWGRP |
+                               stat.S_IXGRP | stat.S_IRWXO)) != stat.S_IWUSR):
+                return _('Permissions of "%s" should be 0600 or 0640') % path
+        return None
+
+    @staticmethod
+    def __validate_name(name):
+        '''Validate the "name" setting.
+
+        Return an error message, or None if no error is detected.
+
+        '''
+        if name == '':
+            return _('The host name may not be empty')
         return None
 
     @staticmethod
@@ -530,6 +587,22 @@ class GlobalDialog(DialogBase):
                self.max_log_file_rotate.get_active())
         self.num_logs.set_sensitive(val)
 
+    def __name_format_not_none_toggled(self, *_):
+        util.set_sensitive_all(self.log_format_raw.get_active() and
+                               self.name_format_not_none.get_active(),
+                               self.name_format_hostname, self.name_format_fqd,
+                               self.name_format_numeric,
+                               self.name_format_user, # self.name excluded
+                               )
+        # Handles self.name
+        self.__name_format_user_toggled()
+
+    def __name_format_user_toggled(self, *_):
+        val = (self.log_format_raw.get_active() and
+               self.name_format_not_none.get_active() and
+               self.name_format_user.get_active())
+        self.name.set_sensitive(val)
+
     def __disk_full_exec_toggled(self, *_):
         util.set_sensitive_all(self.disk_full_exec.get_active(),
                                self.disk_full_exe, self.disk_full_exe_browse)
